%global pkgname polycyclic

# Break the cyclic dependency between alnuth and polycyclic
%bcond_without alnuth

Name:           gap-pkg-%{pkgname}
Version:        2.11
Release:        8%{?dist}
Summary:        Algorithms on polycylic groups for GAP

License:        GPLv2+
URL:            http://www.icm.tu-bs.de/ag_algebra/software/polycyclic/
Source0:        http://www.icm.tu-bs.de/ag_algebra/software/polycyclic/%{pkgname}-%{version}.tar.bz2
BuildArch:      noarch

BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
%if %{with alnuth}
BuildRequires:  gap-pkg-alnuth
%endif
BuildRequires:  gap-pkg-autpgrp

Requires:       gap-core
%if %{with alnuth}
Requires:       gap-pkg-alnuth
%endif
Requires:       gap-pkg-autpgrp

%description
This package provides algorithms for working with polycyclic groups.
The features of this package include:
- creating a polycyclic group from a polycyclic presentation
- arithmetic in a polycyclic group
- computation with subgroups and factor groups of a polycyclic group
- computation of standard subgroup series such as the derived series,
  the lower central series
- computation of the first and second cohomology
- computation of group extensions
- computation of normalizers and centralizers
- solutions to the conjugacy problems for elements and subgroups
- computation of Torsion and various finite subgroups
- computation of various subgroups of finite index
- computation of the Schur multiplicator, the non-abelian exterior
  square and the non-abelian tensor square

%prep
%setup -q -n %{pkgname}-%{version}

# Remove a version control file
rm -f doc/.cvsignore

# Fix character encodings
for fil in etc/style.css gap/basic/colcom.gi; do
  iconv -f iso8859-1 -t utf-8 $fil > $fil.utf8
  touch -r $fil $fil.utf8
  mv -f $fil.utf8 $fil
done

%build
pushd doc
./make_doc
popd

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg/%{pkgname}
cp -a ../%{pkgname}-%{version} %{buildroot}%{_gap_dir}/pkg/
rm -fr %{buildroot}%{_gap_dir}/pkg/%{pkgname}-%{version}/{doc/make_doc,etc}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}-%{version}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,toc}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}-%{version}/{CHANGES,COPYING}
find %{buildroot}%{_gap_dir}/pkg/%{pkgname}-%{version} -name README | \
  xargs rm -f

%if %{with alnuth}
%check
gap -l "%{buildroot}%{_gap_dir}%{_gap_dir}" tst/testall.g 2>&1 | tee log
grep -Evq 'Error|fail' log
rm -f log
%endif

%files
%doc CHANGES README etc/index.html etc/style.css
%license COPYING
%docdir %{_gap_dir}/pkg/%{pkgname}-%{version}/doc
%docdir %{_gap_dir}/pkg/%{pkgname}-%{version}/htm
%{_gap_dir}/pkg/%{pkgname}-%{version}/

%changelog
* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.11-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.11-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 2.11-6
- Rebuild for gap 4.8.3

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.11-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 2.11-4
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source
- Turn test failures into build failures

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun  1 2015 Jerry James <loganjerry@gmail.com> - 2.11-2
- Rebuild with alnuth support

* Wed Mar 25 2015 Jerry James <loganjerry@gmail.com> - 2.11-1
- Initial RPM
